Major changes between releases
==============================


Changes in version 0.2
----------------------

**Released on December 11th, 2015.**

* Migrated `setup.py` from `setuptools` to `distutils` so that the package
  documentation can be properly installed.  As a bonus, this cuts down a
  dependency.

* Fixed contents of the sdist: added missing documentation and `testdata`
  files.  Ah, the obvious mistakes one makes when publishing a Python
  package for the first time...


Changes in version 0.1
----------------------

**Released on December 10th, 2015.**

* First public release.
